#
# spec file for package python-pybeam
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%endif
%if "%{flavor}" == ""
%bcond_with    test
%endif
Name:           python-pybeam%{?psuffix}
Version:        0.8
Release:        1.1
Summary:        Python module to parse Erlang BEAM files
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/matwey/pybeam
Source:         https://files.pythonhosted.org/packages/source/p/pybeam/pybeam-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-construct < 2.11
Requires:       python-construct >= 2.9
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module construct < 2.11}
BuildRequires:  %{python_module construct >= 2.9}
BuildRequires:  %{python_module pybeam}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
Python module to parse Erlang BEAM files, now it is able to read
imports, exports, atoms, as well as compile info and attribute
chunks in pretty python format.

%package -n %{name}-doc
Summary:        API Documentation for %{name}
Group:          Documentation/HTML

%description -n %{name}-doc
Python module to parse Erlang BEAM files, now it is able to read
imports, exports, atoms, as well as compile info and attribute
chunks in pretty python format.

%prep
%autosetup -p1 -n pybeam-%{version}

%build
%if %{without test}
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if %{without test}
%files %{python_files}
%license LICENSE
%{python_sitelib}/pybeam
%{python_sitelib}/pybeam-*-info
%endif

%changelog
* Thu Aug 29 2024 pgajdos@suse.com
- version update to 0.8
  * Use pyproject.toml and drop outdated Python support
  * Drop outdated Python versions from GitHub Actions
  * Initial support for gzip compressed BEAM files
* Thu Nov  5 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 0.7
- Fix CInf parse
- Drop make_sphinx_optional.patch
* Fri Feb 14 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 0.6
* Wed Feb 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove doc conditional as it is never built due to always being
  as a bcond_with
- Use unittest directly to avoid setup.py test deprecation
- Allow usage with construct 2.10
* Sun Dec 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make Sphinx dependency optional (docs are not built by default),
  add make_sphinx_optional.patch
- Use _multibuild for tests to reduce the build dependencies
  and simplify bootstrap for e.g. rpmlint.
* Fri Jan 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Wed Dec 26 2018 matwey.kornilov@gmail.com
- Version 0.5
  - ported to construct 2.9.x
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Mar 19 2018 matwey.kornilov@gmail.com
- Version 0.4.1 (bsc#1089748):
  - Add support for AtU8 chuck (fix Erlang 20.0 beam file format)
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Fri Jan 20 2017 matwey.kornilov@gmail.com
- Version 0.4:
  - ported to construct 2.8.x
* Wed Jan 18 2017 matwey.kornilov@gmail.com
- Update Source url
* Sun Jan  8 2017 matwey.kornilov@gmail.com
- Only consruct 2.5.x is supported by pybeam 0.3.x
* Sat May 31 2014 matwey.kornilov@gmail.com
- Version 0.3.2:
  - add support for Erlang 17.0 (maps)
* Sat Mar 29 2014 matwey.kornilov@gmail.com
- Verision 0.3.1:
  - fix parsing lists with not-null tail
  - fix parsing strings ( six > 1.4.0 is required to support both
    python 2 and python 3 )
* Thu Feb 20 2014 matwey.kornilov@gmail.com
- Version 0.3:
  - python 3.3 support
  - minor fixes and add more unit-tests
  - Code LitT FunT chunk now understood
* Mon May  6 2013 matwey.kornilov@gmail.com
- Version 0.2:
  - fixed floating point parsing
  - fixed Atom lists indexation
* Wed May  1 2013 matwey.kornilov@gmail.com
- Initial version
